@@ -3,12 +3,26 @@ package DBIx::Class::Migration::RunScript;
 use Moose;
 use Moose::Exporter;
 use Text::Brew qw(distance);
+use Log::Any;
+use Carp 'croak';
 
 Moose::Exporter->setup_import_methods(
   as_is => ['builder', 'migrate']);
 
 with 'MooseX::Traits::Pluggable';
 
+sub _log_die {
+  my ($self, $msg) = @_;
+  $self->log->error($msg);
+  croak $msg;
+}
+
+has log => (
+    is  => 'ro',
+    isa => 'Log::Any::Proxy',
+    default => sub { Log::Any->get_logger( category => 'DBIx::Class::Migration') },
+);
+
 has '+_trait_namespace' => (default=>'+Trait');
 has 'dbh' => (is=>'rw', isa=>'Object');
 has 'version_set' => (is=>'rw', isa=>'ArrayRef');
@@ -30,7 +44,7 @@ sub handle_errors {
       (distance($_, $1))[0] < 3 ? "$_ <== Possible Match\n" : "$_\n";
     } $self->schema->sources;
 
-    die <<"ERR";
+    $self->_log_die(<<"ERR");
 $err
 You are probably seeing this error because the DBIC source in your migration
 script called "$1" doesn't match a source defined in the schema that
@@ -52,7 +66,7 @@ ERR
     } ($self->schema->resultset($2)->result_source->columns,
         $self->schema->resultset($2)->result_source->relationships);
 
-    die <<"ERR";
+    $self->_log_die(<<"ERR");
 $err
 You are probably seeing this error because the DBIC resultset $2 does
 not have a column or method called $1 defined in the schema which
@@ -69,7 +83,7 @@ that $2 has available:
  @presentsources
 ERR
   } else {
-    die $err;
+    $self->_log_die($err);
   }
 }
 
